@@ -2,7 +2,7 @@ import datetime
 
 from flask import request, redirect, url_for, render_template, flash
 
-from flaskext.utils import get_object_or_404, object_list
+from flask_peewee.utils import get_object_or_404, object_list
 
 from app import app
 from auth import auth
