@@ -12,7 +12,7 @@ from flask_peewee.forms import BooleanSelectField, ForeignKeyField, CustomModelC
 from flask_peewee.filters import QueryFilter, lookups_for_field, Lookup, FIELD_TYPES
 from flask_peewee.serializer import Serializer
 from flask_peewee.utils import get_next, PaginatedQuery, path_to_models, slugify
-from peewee import BooleanField, DateTimeField, ForeignKeyField
+from peewee import BooleanField, DateTimeField, ForeignKeyField, DateField
 from werkzeug import Headers
 from wtforms import fields, widgets
 from wtfpeewee.fields import ModelSelectField, ModelSelectMultipleField
@@ -32,6 +32,9 @@ class FieldValueMap(object):
             (DateTimeField, 'today'): self.handle_dummy,
             (DateTimeField, 'yesterday'): self.handle_dummy,
             (DateTimeField, 'this_week'): self.handle_dummy,
+            (DateField, 'today'): self.handle_dummy,
+            (DateField, 'yesterday'): self.handle_dummy,
+            (DateField, 'this_week'): self.handle_dummy,
             (ForeignKeyField, 'eq'): self.handle_foreign_key,
             (ForeignKeyField, 'in'): self.handle_foreign_key_multi,
         }
@@ -354,7 +357,7 @@ class ModelAdmin(object):
         if request.method == 'POST':
             raw_fields = request.form.getlist('fields')
             export = Export(filtered_query, related, raw_fields)
-            return export.json_response()
+            return export.json_response('export-%s.json' % self.get_admin_name())
 
         lookups, active_lookups = self.get_lookups()
 
@@ -653,7 +656,7 @@ class Export(object):
         clone.query = select
         return clone
 
-    def json_response(self):
+    def json_response(self, filename='export.json'):
         serializer = Serializer()
         prepared_query = self.prepare_query()
 
@@ -668,5 +671,5 @@ class Export(object):
             yield '\n]'
         headers = Headers()
         headers.add('Content-Type', 'application/javascript')
-        headers.add('Content-Disposition', 'attachment; filename=export.json')
+        headers.add('Content-Disposition', 'attachment; filename=%s' % filename)
         return Response(generate(), mimetype='text/javascript', headers=headers, direct_passthrough=True)
